@@ -1,6 +1,7 @@
 use regex::Regex;
 use std::collections::HashMap;
 use std::env;
+use std::ffi::OsString;
 use std::fmt;
 use std::process::Command;
 
@@ -22,15 +23,15 @@ impl fmt::Display for PythonVersion {
     }
 }
 
-const CFG_KEY: &'static str = "py_sys_config";
+const CFG_KEY: &str = "py_sys_config";
 
 // windows' python writes out lines with the windows crlf sequence;
 // posix platforms and mac os should write out lines with just lf.
 #[cfg(target_os = "windows")]
-static NEWLINE_SEQUENCE: &'static str = "\r\n";
+static NEWLINE_SEQUENCE: &str = "\r\n";
 
 #[cfg(not(target_os = "windows"))]
-static NEWLINE_SEQUENCE: &'static str = "\n";
+static NEWLINE_SEQUENCE: &str = "\n";
 
 // A list of python interpreter compile-time preprocessor defines that
 // we will pick up and pass to rustc via --cfg=py_sys_config={varname};
@@ -45,7 +46,7 @@ static NEWLINE_SEQUENCE: &'static str = "\n";
 // (hrm, this is sort of re-implementing what distutils does, except
 // by passing command line args instead of referring to a python.h)
 #[cfg(not(target_os = "windows"))]
-static SYSCONFIG_FLAGS: [&'static str; 7] = [
+static SYSCONFIG_FLAGS: [&str; 7] = [
     "Py_USING_UNICODE",
     "Py_UNICODE_WIDE",
     "WITH_THREAD",
@@ -55,7 +56,7 @@ static SYSCONFIG_FLAGS: [&'static str; 7] = [
     "COUNT_ALLOCS",
 ];
 
-static SYSCONFIG_VALUES: [&'static str; 1] = [
+static SYSCONFIG_VALUES: [&str; 1] = [
     // cfg doesn't support flags with values, just bools - so flags
     // below are translated into bools as {varname}_{val}
     //
@@ -63,11 +64,16 @@ static SYSCONFIG_VALUES: [&'static str; 1] = [
     "Py_UNICODE_SIZE", // note - not present on python 3.3+, which is always wide
 ];
 
+fn watched_var_os(key: &str) -> Option<OsString> {
+    println!("cargo:rerun-if-env-changed={}", key);
+    env::var_os(key)
+}
+
 /// Examine python's compile flags to pass to cfg by launching
 /// the interpreter and printing variables of interest from
 /// sysconfig.get_config_vars.
 #[cfg(not(target_os = "windows"))]
-fn get_config_vars(python_path: &String) -> Result<HashMap<String, String>, String> {
+fn get_config_vars(python_path: &str) -> Result<HashMap<String, String>, String> {
     let mut script = "import sysconfig; \
                       config = sysconfig.get_config_vars();"
         .to_owned();
@@ -78,7 +84,7 @@ fn get_config_vars(python_path: &String) -> Result<HashMap<String, String>, Stri
             k,
             if is_value(k) { "None" } else { "0" }
         ));
-        script.push_str(";");
+        script.push(';');
     }
 
     let mut cmd = Command::new(python_path);
@@ -90,7 +96,7 @@ fn get_config_vars(python_path: &String) -> Result<HashMap<String, String>, Stri
 
     if !out.status.success() {
         let stderr = String::from_utf8(out.stderr).unwrap();
-        let mut msg = format!("python script failed with stderr:\n\n");
+        let mut msg = "python script failed with stderr:\n\n".to_string();
         msg.push_str(&stderr);
         return Err(msg);
     }
@@ -102,15 +108,14 @@ fn get_config_vars(python_path: &String) -> Result<HashMap<String, String>, Stri
             "python stdout len didn't return expected number of lines:
 {}",
             split_stdout.len()
-        )
-        .to_string());
+        ));
     }
     let all_vars = SYSCONFIG_FLAGS.iter().chain(SYSCONFIG_VALUES.iter());
     // let var_map: HashMap<String, String> = HashMap::new();
     Ok(all_vars.zip(split_stdout.iter()).fold(
         HashMap::new(),
         |mut memo: HashMap<String, String>, (&k, &v)| {
-            if !(v.to_owned() == "None" && is_value(k)) {
+            if !(v == "None" && is_value(k)) {
                 memo.insert(k.to_owned(), v.to_owned());
             }
             memo
@@ -119,7 +124,7 @@ fn get_config_vars(python_path: &String) -> Result<HashMap<String, String>, Stri
 }
 
 #[cfg(target_os = "windows")]
-fn get_config_vars(_: &String) -> Result<HashMap<String, String>, String> {
+fn get_config_vars(_: &str) -> Result<HashMap<String, String>, String> {
     // sysconfig is missing all the flags on windows, so we can't actually
     // query the interpreter directly for its build flags.
     //
@@ -148,7 +153,7 @@ fn get_config_vars(_: &String) -> Result<HashMap<String, String>, String> {
 }
 
 fn is_value(key: &str) -> bool {
-    SYSCONFIG_VALUES.iter().find(|x| **x == key).is_some()
+    SYSCONFIG_VALUES.iter().any(|x| *x == key)
 }
 
 fn cfg_line_for_var(key: &str, val: &str) -> Option<String> {
@@ -182,17 +187,17 @@ fn run_python_script(interpreter: &str, script: &str) -> Result<String, String>
 
     if !out.status.success() {
         let stderr = String::from_utf8(out.stderr).unwrap();
-        let mut msg = format!("python script failed with stderr:\n\n");
+        let mut msg = "python script failed with stderr:\n\n".to_string();
         msg.push_str(&stderr);
         return Err(msg);
     }
 
-    let out = String::from_utf8(out.stdout).unwrap();
-    return Ok(out);
+    Ok(String::from_utf8(out.stdout).unwrap())
 }
 
 #[cfg(not(target_os = "macos"))]
 #[cfg(not(target_os = "windows"))]
+#[allow(clippy::unnecessary_wraps)]
 fn get_rustc_link_lib(
     _: &PythonVersion,
     ld_version: &str,
@@ -268,14 +273,14 @@ fn matching_version(expected_version: &PythonVersion, actual_version: &PythonVer
 fn find_interpreter_and_get_config(
     expected_version: &PythonVersion,
 ) -> Result<(PythonVersion, String, Vec<String>), String> {
-    if let Some(sys_executable) = env::var_os("PYTHON_SYS_EXECUTABLE") {
+    if let Some(sys_executable) = watched_var_os("PYTHON_SYS_EXECUTABLE") {
         let interpreter_path = sys_executable
             .to_str()
             .expect("Unable to get PYTHON_SYS_EXECUTABLE value");
         let (executable, interpreter_version, lines) =
             get_config_from_interpreter(interpreter_path)?;
         if matching_version(expected_version, &interpreter_version) {
-            return Ok((interpreter_version, executable.to_owned(), lines));
+            return Ok((interpreter_version, executable, lines));
         } else {
             return Err(format!(
                 "Wrong python version in PYTHON_SYS_EXECUTABLE={}\n\
@@ -294,11 +299,9 @@ fn find_interpreter_and_get_config(
     }
 
     for name in possible_names.iter() {
-        if let Some((executable, interpreter_version, lines)) =
-            get_config_from_interpreter(name).ok()
-        {
+        if let Ok((executable, interpreter_version, lines)) = get_config_from_interpreter(name) {
             if matching_version(expected_version, &interpreter_version) {
-                return Ok((interpreter_version, executable.to_owned(), lines));
+                return Ok((interpreter_version, executable, lines));
             }
         }
     }
@@ -341,10 +344,10 @@ fn configure_from_path(expected_version: &PythonVersion) -> Result<String, Strin
     let ld_version: &str = &lines[2];
     let exec_prefix: &str = &lines[3];
 
-    let is_extension_module = env::var_os("CARGO_FEATURE_EXTENSION_MODULE").is_some();
-    let mut link_mode_default = env::var_os("CARGO_FEATURE_LINK_MODE_DEFAULT").is_some();
+    let is_extension_module = watched_var_os("CARGO_FEATURE_EXTENSION_MODULE").is_some();
+    let mut link_mode_default = watched_var_os("CARGO_FEATURE_LINK_MODE_DEFAULT").is_some();
     let link_mode_unresolved_static =
-        env::var_os("CARGO_FEATURE_LINK_MODE_UNRESOLVED_STATIC").is_some();
+        watched_var_os("CARGO_FEATURE_LINK_MODE_UNRESOLVED_STATIC").is_some();
 
     if link_mode_default && link_mode_unresolved_static {
         return Err(
@@ -368,20 +371,18 @@ fn configure_from_path(expected_version: &PythonVersion) -> Result<String, Strin
                 println!("cargo:rustc-link-search=native={}\\libs", exec_prefix);
             }
         }
-    } else if link_mode_unresolved_static {
-        if cfg!(target_os = "windows") {
-            // static-nobundle requires a Nightly rustc up to at least
-            // Rust 1.39 (https://github.com/rust-lang/rust/issues/37403).
-            //
-            // We need to use static linking on Windows to prevent symbol
-            // name mangling. Otherwise Rust will prefix extern {} symbols
-            // with __imp_. But if we used normal "static," we need a
-            // pythonXY.lib at build time to package into the rlib.
-            //
-            // static-nobundle removes the build-time library requirement,
-            // allowing a downstream consumer to provide the pythonXY library.
-            println!("cargo:rustc-link-lib=static-nobundle=pythonXY");
-        }
+    } else if link_mode_unresolved_static && cfg!(target_os = "windows") {
+        // static-nobundle requires a Nightly rustc up to at least
+        // Rust 1.39 (https://github.com/rust-lang/rust/issues/37403).
+        //
+        // We need to use static linking on Windows to prevent symbol
+        // name mangling. Otherwise Rust will prefix extern {} symbols
+        // with __imp_. But if we used normal "static," we need a
+        // pythonXY.lib at build time to package into the rlib.
+        //
+        // static-nobundle removes the build-time library requirement,
+        // allowing a downstream consumer to provide the pythonXY library.
+        println!("cargo:rustc-link-lib=static-nobundle=pythonXY");
     }
 
     if let PythonVersion {
@@ -389,7 +390,7 @@ fn configure_from_path(expected_version: &PythonVersion) -> Result<String, Strin
         minor: some_minor,
     } = interpreter_version
     {
-        if env::var_os("CARGO_FEATURE_PEP_384").is_some() {
+        if watched_var_os("CARGO_FEATURE_PEP_384").is_some() {
             println!("cargo:rustc-cfg=Py_LIMITED_API");
         }
         if let Some(minor) = some_minor {
@@ -399,7 +400,7 @@ fn configure_from_path(expected_version: &PythonVersion) -> Result<String, Strin
         }
     }
 
-    return Ok(interpreter_path);
+    Ok(interpreter_path)
 }
 
 /// Determine the python version we're supposed to be building
@@ -415,17 +416,11 @@ fn version_from_env() -> Result<PythonVersion, String> {
     let mut vars = env::vars().collect::<Vec<_>>();
     vars.sort_by(|a, b| b.cmp(a));
     for (key, _) in vars {
-        match re.captures(&key) {
-            Some(cap) => {
-                return Ok(PythonVersion {
-                    major: cap.get(1).unwrap().as_str().parse().unwrap(),
-                    minor: match cap.get(3) {
-                        Some(s) => Some(s.as_str().parse().unwrap()),
-                        None => None,
-                    },
-                })
-            }
-            None => (),
+        if let Some(cap) = re.captures(&key) {
+            return Ok(PythonVersion {
+                major: cap.get(1).unwrap().as_str().parse().unwrap(),
+                minor: cap.get(3).map(|s| s.as_str().parse().unwrap()),
+            });
         }
     }
     Err(
@@ -456,9 +451,8 @@ fn main() {
         config_map.insert("Py_REF_DEBUG".to_owned(), "1".to_owned()); // Py_TRACE_REFS implies Py_REF_DEBUG.
     }
     for (key, val) in &config_map {
-        match cfg_line_for_var(key, val) {
-            Some(line) => println!("{}", line),
-            None => (),
+        if let Some(line) = cfg_line_for_var(key, val) {
+            println!("{}", line);
         }
     }
 
@@ -486,7 +480,7 @@ fn main() {
     });
     println!(
         "cargo:python_flags={}",
-        if flags.len() > 0 {
+        if !flags.is_empty() {
             &flags[..flags.len() - 1]
         } else {
             ""
