@@ -1,6 +1,3 @@
-extern crate libc;
-extern crate python3_sys;
-
 unsafe fn get_str<'a>(s: *const libc::c_char) -> &'a str {
     let bytes = std::ffi::CStr::from_ptr(s).to_bytes();
     std::str::from_utf8(bytes).unwrap()
